# Careers

Want to help create a new product and make an impact in the world of data? You are in luck because we're hiring!

## Open Positions

Here are the open positions that we currently have:

- [Senior Product Manager](https://boards.greenhouse.io/gitlab/jobs/4059265002)

## Benefits

For our benefits, please check out the [GitLab Handbook](https://about.gitlab.com/handbook/benefits/) for more information.
